@@ -1,5 +1,5 @@
 use super::*;
-use alloc::vec::Vec;
+use alloc::{string::String, vec::Vec};
 
 #[derive(Debug)]
 pub struct ContractAbi {
@@ -22,4 +22,13 @@ impl ContractAbi {
     pub fn add_type_descriptions<T: TypeAbi>(&mut self) {
         T::provide_type_descriptions(&mut self.type_descriptions);
     }
+
+    /// Crate name, but with underscores instead of dashes.
+    pub fn get_module_name(&self) -> String {
+        self.build_info
+            .contract_crate
+            .name
+            .replace('-', "_")
+            .to_lowercase()
+    }
 }
