@@ -12,6 +12,7 @@ mod managed_byte_array;
 mod managed_conversion;
 mod managed_default;
 mod managed_multi_result_vec;
+mod managed_multi_result_vec_counted;
 mod managed_multi_result_vec_iter;
 mod managed_ref;
 mod managed_type_trait;
@@ -29,7 +30,8 @@ pub(crate) use managed_byte_array::ManagedBufferSizeContext;
 pub use managed_byte_array::ManagedByteArray;
 pub use managed_conversion::{ManagedFrom, ManagedInto};
 pub use managed_default::ManagedDefault;
-pub use managed_multi_result_vec::ManagedMultiResultVec;
+pub use managed_multi_result_vec::{ManagedMultiResultVec, ManagedVarArgs};
+pub use managed_multi_result_vec_counted::{ManagedCountedMultiResultVec, ManagedCountedVarArgs};
 pub use managed_multi_result_vec_iter::ManagedMultiResultVecIterator;
 pub use managed_ref::{AsManagedRef, ManagedRef};
 pub use managed_type_trait::ManagedType;
