@@ -2,9 +2,13 @@ mod crypto;
 mod general;
 mod interaction;
 mod io;
+mod managed;
+mod managed_codec;
 
 pub use super::{Box, Vec};
 pub use crypto::*;
 pub use general::*;
 pub use interaction::*;
 pub use io::*;
+pub use managed::*;
+pub use managed_codec::*;
